@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0700';
 
 use Moo;
 use MIDI::Simple;
@@ -17,7 +17,7 @@ sub BUILD {
     $self->divisions($divisions);
     $self->score->time_signature(
         $self->beats,
-        sqrt( $self->divisions ),
+        ( $self->divisions == 8 ? 3 : 2),
         ( $self->divisions == 8 ? 24 : 18 ),
         8
     );
@@ -130,7 +130,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.0601
+version 0.0700
 
 =head1 SYNOPSIS
 
